SniResolverLock

Type Alias SniResolverLock 

pub type SniResolverLock = Arc<RwLock<HostnameRadixTree<Arc<dyn ResolvesServerCert>>>>;
The type for the SNI resolver lock, which is a vector of tuples containing the hostname and the corresponding certificate resolver.

Aliased Type

pub struct SniResolverLock { /* private fields */ }